Package: breakDown
Title: Model Agnostic Explainers for Individual Predictions
Version: 0.1.6
Authors@R: c(person("Przemyslaw", "Biecek", email = "przemyslaw.biecek@gmail.com", role = c("aut", "cre")),
    person("Aleksandra", "Grudziaz", email = "aleksandra.grudziaz@gmail.com", role = "ctb"))
Description: Model agnostic tool for decomposition of predictions from black boxes.
    Break Down Table shows contributions of every variable to a final prediction. 
    Break Down Plot presents variable contributions in a concise graphical way. 
    This package work for binary classifiers and general regression models. 
Depends: R (>= 3.0)
Date: 2018-06-11
License: GPL-2
Encoding: UTF-8
LazyData: true
Imports: ggplot2
RoxygenNote: 6.0.1
Suggests: knitr, rmarkdown, e1071, kernlab, xgboost, caret,
        randomForest, ranger, testthat
VignetteBuilder: knitr
URL: https://pbiecek.github.io/breakDown/
BugReports: https://github.com/pbiecek/breakDown/issues
NeedsCompilation: no
Packaged: 2018-06-11 21:54:18 UTC; pbiecek
Author: Przemyslaw Biecek [aut, cre],
  Aleksandra Grudziaz [ctb]
Maintainer: Przemyslaw Biecek <przemyslaw.biecek@gmail.com>
Repository: CRAN
Date/Publication: 2018-06-14 18:33:11 UTC
Built: R 3.5.1; ; 2018-09-20 13:08:23 UTC; windows
