# Generated by roxygen2: do not edit by hand

S3method(broken,default)
S3method(broken,glm)
S3method(broken,lm)
S3method(plot,broken)
S3method(print,broken)
export(betas)
export(broken)
import(ggplot2)
importFrom(stats,coef)
importFrom(stats,delete.response)
importFrom(stats,model.matrix)
importFrom(stats,predict)
importFrom(stats,predict.glm)
importFrom(stats,predict.lm)
importFrom(stats,terms)
